/****************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the documentation of Qt. It was originally
** published as part of Qt Quarterly.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QGeoBoundingBox>
#include <QGeoCoordinate>
#include "maplabel.h"

using namespace QtMobility;

MapLabel::MapLabel(QGeoMappingManager *manager, QWidget *parent)
    : QLabel(parent), manager(manager)
{
    QPixmap pixmap(300, 300);
    pixmap.fill(QColor(255, 255, 255));
    setPixmap(pixmap);

    mapData = manager->createMapData();
    connect(mapData, SIGNAL(updateMapDisplay(const QRectF &)),
            this, SLOT(updateMap(const QRectF &)));

    mapData->setWindowSize(QSizeF(300, 300));
    mapData->fitInViewport(
        QGeoBoundingBox(QGeoCoordinate(37.8, -25.75),
                                       0.20598828792572021, 0.16276264821291164));
    mapData->setMapType(QGraphicsGeoMap::TerrainMap);
    mapData->setZoomLevel(10);
}

void MapLabel::updateMap(const QRectF &rectangle)
{
    Q_UNUSED(rectangle)

    QPixmap px(*pixmap());

    QPainter painter;
    painter.begin(&px);
    mapData->paint(&painter, 0);
    painter.end();

    setPixmap(px);
}
